@@ -1,7 +1,7 @@
 # copyright (C) 1997-98 Jean-Luc Fontaine (mailto:jfontain@mygale.org)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: blt2d.tcl,v 1.24 1998/06/21 12:04:32 jfontain Exp $}
+set rcsId {$Id: blt2d.tcl,v 1.25 1998/10/10 20:58:19 jfontain Exp $}
 
 class blt2DViewer {
 
@@ -82,11 +82,7 @@ if {$::officialBLT} {
     }
 
     proc cells {this} {
-        set list {}
-        foreach element $blt2DViewer::($this,elements) {
-            lappend list $blt2DViewer::($this,cell,$element)
-        }
-        return $list
+        return [cellsFromElements $this $blt2DViewer::($this,elements)]
     }
 
     proc deletedElement {this array element} {
