@@ -1,7 +1,7 @@
 # copyright (C) 1997-98 Jean-Luc Fontaine (mailto:jfontain@mygale.org)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: datatab.tcl,v 1.43 1998/08/01 19:19:36 jfontain Exp $}
+set rcsId {$Id: datatab.tcl,v 1.45 1998/10/10 20:56:43 jfontain Exp $}
 
 class dataTable {                       ;# module data view in the form of a table, that can be sorted using a column as a reference
 
@@ -10,18 +10,18 @@ class dataTable {                       ;# module data view in the form of a tab
     set dataTable::(scrollbarBorderWidth) [expr {$widget::(default,ScrollbarBorderWidth)==0?0:1}]
     set dataTable::(scrollbarWidth) [expr {2*$widget::(default,ScrollbarWidth)/3}]
 
-    proc dataTable {this parentPath args} composite {[new scroll table $parentPath] $args} {
-
-        widget::configure $composite::($this,base) horizontal\
-            -width $dataTable::(scrollbarWidth) -borderwidth $dataTable::(scrollbarBorderWidth)
-        widget::configure $composite::($this,base) vertical\
-            -width $dataTable::(scrollbarWidth) -borderwidth $dataTable::(scrollbarBorderWidth)
-
+    proc dataTable {this parentPath args} composite {
+        [new scroll table $parentPath\
+            -scrollbarwidth $dataTable::(scrollbarWidth) -scrollbarelementborderwidth $dataTable::(scrollbarBorderWidth)\
+        ]
+        $args
+    } {
         set path $composite::($composite::($this,base),scrolled,path)
         # only allow interactive colun resizing
         # use arrow cursor instead of default insertion cursor, meaningless since cell editing is disabled
         $path configure -font $font::(mediumNormal) -rows 2 -state disabled -titlerows 1 -roworigin -1 -colstretchmode unset\
-            -variable dataTable::${this}data -resizeborders col -cursor {} -bordercursor sb_h_double_arrow
+            -variable dataTable::${this}data -resizeborders col -cursor {} -bordercursor sb_h_double_arrow -highlightthickness 0\
+            -takefocus 0
         $path tag configure select -background white
 
         bindtags $path "$path . all"           ;# remove all class bindings for we do not use any and they would cause interferences
@@ -68,7 +68,7 @@ class dataTable {                       ;# module data view in the form of a tab
         if {[string length $composite::($this,-data)]==0} return                                         ;# nothing to do if no data
 
         set path $dataTable::($this,tablePath)
-        for {set column 0} {$column<[llength $dataTable::($this,dataColumns]} {incr column} {
+        for {set column 0} {$column<[llength $dataTable::($this,dataColumns)]} {incr column} {
             $path.$column.label configure -font $value
         }
     }
