@@ -1,20 +1,7 @@
 # copyright (C) 1997-98 Jean-Luc Fontaine (mailto:jfontain@mygale.org)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: drag.tcl,v 1.20 1998/07/26 10:36:57 jfontain Exp $}
-
-### the following code should be moved to scwoop utilities and also used there in all related files ###
-if {[string compare $::tcl_platform(platform) windows]==0} {                    ;# compensate for win32 bug (thanks to Robin Becker)
-    proc showTopLevel {path geometry} {
-        wm deiconify $path
-        wm geometry $path $geometry
-    }
-} else {
-    proc showTopLevel {path geometry} {
-        wm geometry $path $geometry
-        wm deiconify $path
-    }
-}
+set rcsId {$Id: drag.tcl,v 1.22 1998/10/11 20:40:42 jfontain Exp $}
 
 class dragSite {                                          ;# make a Tk widget a drag site with multiple formats support for its data
 
@@ -66,7 +53,6 @@ class dragSite {                                          ;# make a Tk widget a
         set draggable($value) {}                                                                     ;# register path as a drag site
         set dragSite::($this,bindings) [new bindings $value end]                          ;# do not interfere with existing bindings
         bindings::set $dragSite::($this,bindings) <ButtonPress-1> "dragSite::hit $this %x %y %X %Y"
-        bindings::set $dragSite::($this,bindings) <Destroy> "delete $this"          ;# self destruct when source widget is destroyed
     }
 
     proc set-validcommand {this value} {}       ;# command is invoked with x and y hit coordinates for widget, must return a boolean
