@@ -1,7 +1,7 @@
 # copyright (C) 1997-98 Jean-Luc Fontaine (mailto:jfontain@mygale.org)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: drop.tcl,v 1.10 1998/05/24 19:24:43 jfontain Exp $}
+set rcsId {$Id: drop.tcl,v 1.11 1998/10/09 19:35:44 jfontain Exp $}
 
 class dropSite {
     set dropSite::(list) {}                                                                            ;# initialize list of objects
@@ -61,7 +61,7 @@ class dropSite {
                 if {[lsearch -exact $formats $format]>=0} {
                     set path $switched::($site,-path)
                     set x [winfo rootx $path]; set y [winfo rooty $path]
-                    lappend regions [list $site $x $y [expr {$x+[winfo width $path]}] [expr $y+{[winfo height $path]}]]
+                    lappend regions [list $site $x $y [expr {$x+[winfo width $path]}] [expr {$y+[winfo height $path]}]]
                     break                               ;# drop site will accept at least one of the data formats from the drag site
                 }
             }
