@@ -1,7 +1,7 @@
 # copyright (C) 1997-98 Jean-Luc Fontaine (mailto:jfontain@mygale.org)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: help.tcl,v 1.23 1998/06/13 21:11:15 jfontain Exp $}
+set rcsId {$Id: help.tcl,v 1.25 1998/10/11 09:32:49 jfontain Exp $}
 
 namespace eval help {
 
@@ -123,7 +123,6 @@ proc aboutDialogBox {} {
     grid columnconfigure $frame 1 -weight 1
     grid $widget::($text,path) -row 1 -column 0 -columnspan 2 -sticky nsew
 
-    set TRANSPARENT_GIF_COLOR [$frame cget -background]
     grid [label $frame.icon -image [image create photo -data [dataGraph::iconData]]] -row 0 -column 0
     grid [label $frame.name -text $help::nameAndVersion] -row 0 -column 1
 
@@ -141,3 +140,26 @@ proc modulesHelpDialogBox {args} {
     }
     simpleTextDialogBox {moodss: Modules Help} $text
 }
+
+proc versionsDialogBox {} {
+    array set ::versionsData {
+        updates 0
+        0,label file 0,type ascii 0,message {source file name}
+        1,label version 1,type dictionary 1,message {version}
+        sort {0 increasing}
+        indexColumns 0
+    }
+    set row 0
+    foreach name [array names ::sourceVersion] {
+        set ::versionsData($row,0) $name
+        set ::versionsData($row,1) $::sourceVersion($name)
+        incr row
+    }
+    set dialog [new dialogBox .\
+        -buttons o -default o -title {moodss: Source Versions} -command {unset ::versionsData}\
+        -x [winfo pointerx .] -y [winfo pointery .]\
+    ]
+    set table [new dataTable $widget::($dialog,path) -data ::versionsData]
+    incr ::versionsData(updates)
+    dialogBox::display $dialog $widget::($table,path)
+}
