@@ -97,21 +97,22 @@ displays, curves, pie charts, multiple configuration dialog boxes, even
 3D visualization modules to present network traffic, connection matrices,
 ...
 <P>In most cases, data comes from one or several tables. A common interface,
-graphical with menus, drag'n'drop capability, table widgets and graphical
-data viewers such as multiple line graphs, bar and pie charts, could be
-used. The user could then sort table rows, select one or more cells, rows,
-columns, to launch viewers such as other tables, charts, ... best suited
-to the way data should be presented. In effect, what is needed is a spreadsheet
-that is capable of dealing with dynamically changing data.
+graphical with menus, drag'n'drop capability, table widgets, textual and
+graphical data viewers such as multiple line graphs, bar and pie charts,
+could be used. The user could then sort table rows, select one or more
+cells, rows, columns, to launch viewers such as other tables, charts, ...
+best suited to the way data should be presented. In effect, what is needed
+is a spreadsheet that is capable of dealing with dynamically changing data.
 <P>Moodss (Modular Object Oriented Dynamic SpreadSheet) is an attempt at
 answering these needs. It is composed of a main part (the core) and an
-unlimited number of modules, each module interfacing to a specific type
-of data. The core is written in the great Tcl language (<A HREF="http://www.scriptics.com/">http://www.scriptics.com/</A>
-) using object oriented techniques thanks to the stooop and scwoop packages
-(<A HREF="http://www.mygale.org/~jfontain/">http://www.mygale.org/~jfontain/</A>).
+unlimited number of modules, loaded as the application is launched, each
+module interfacing to a specific type of data. The core is written in the
+great Tcl language (at <A HREF="http://www.scriptics.com/">http://www.scriptics.com/</A>)
+using object oriented techniques thanks to the stooop and scwoop packages
+(at <A HREF="http://www.mygale.org/~jfontain/">http://www.mygale.org/~jfontain/</A>).
 The module function is to describe the type of data that it is also in
 charge of retrieving and formatting. Modules can be written in plain Tcl
-and optionally use dynamically linked libraries written in the C language
+or C and optionally use dynamically linked libraries written in the C language
 (modules are packages in the Tcl sense).
 <P>Modules are loaded when moodss is started. One or more modules can be
 handled concurrently (starting with moodss version 3.0). This way, you
@@ -151,7 +152,7 @@ rpm file (available (starting with 4.4) at <A HREF="http://www.mygale.org/~jfont
 for installation. It includes all the required software (except Tcl/Tk
 8.x, of course). If you want to work on the moodss source code, see below,
 otherwise you can skip the rest of this section.
-<P>For the current version (4.4), the following packages must be installed
+<P>For the current version (5.0), the following packages must be installed
 before attempting to install moodss (make sure to check the INSTALL file
 for the latest information):
 <UL>
@@ -162,7 +163,7 @@ Tcl/Tk version 8.0 or above (at <A HREF="http://sunscript.sun.com/">http://sunsc
 tkTable version 2.0 or above (at <A HREF="http://oprs.mchh.siemens.de/tcl/capp/tkTable/">http://oprs.mchh.siemens.de/tcl/capp/tkTable/</A>)<B>*</B></LI>
 
 <LI>
-the BLT library for Tcl/Tk 8.0/8.1 (at <A HREF="ftp://ftp.tcltk.com/pub/blt/">ftp://ftp.tcltk.com/pub/blt/</A>)<B>*</B></LI>
+the BLT library version 2.4 (at <A HREF="ftp://ftp.tcltk.com/pub/blt/">ftp://ftp.tcltk.com/pub/blt/</A>)<B>*</B></LI>
 </UL>
 
 <DIV ALIGN=right><B>*</B><I> many thanks to the authors for these great
@@ -175,10 +176,13 @@ to work on the moodss source code itself. However, should you want to get
 more information on those extensions, you could find the latest versions:
 <UL>
 <LI>
-stooop version 3.6 or above</LI>
+stooop version 3.6.1 or above</LI>
 
 <LI>
-scwoop version 2.2 or above</LI>
+switched version 1.4 or above (included in the stooop distribution)</LI>
+
+<LI>
+scwoop version 2.5 or above</LI>
 
 <LI>
 tkpiechart version 5.2 or above</LI>
@@ -188,7 +192,8 @@ all at <A HREF="http://www.mygale.org/~jfontain/">http://www.mygale.org/~jfontai
 <A NAME="architecture"></A>4. Architecture</H3>
 The moodss application is composed of the core software and one or several
 modules. Modules are implemented as Tcl packages and thus usually comprise
-a Tcl source file and a pkgIndex.tcl file required by the Tcl package implementation.
+a Tcl source file and a pkgIndex.tcl file as required by the Tcl package
+implementation.
 <P>The core will load one or more modules, whose names were passed as command
 line parameters or come from a save file, and will start displaying module
 data in one or more tables. The tables are then updated at the frequency
@@ -205,18 +210,19 @@ is asynchronous, its data may be updated at any time. The synchronous or
 asynchronous nature is specified in the configuration data for the module.
 <P>The initial data tables represent the first data views, from which cells
 can be selected and when dropped through a drag'n'drop operation into a
-graph, bar chart, pie chart or summary table iconic site, result in the
-creation of data viewers. In turn, these viewers can display more table
-cells, which when dropped into the viewer, result in the creation of corresponding
-data graph lines, chart bars, pie slices or table rows.
+graph, bar chart, pie chart, summary table or free text iconic site, result
+in the creation of data viewers. In turn, these viewers can display more
+table cells, which when dropped into the viewer, result in the creation
+of corresponding data graph lines, chart bars, pie slices, table rows or
+text cells.
 <P>Any draggable data can be dropped in valid drop sites at any time. It
 is thus possible to drag several data cells from any table or any viewer
 into other ones, the trash, ... even if the data comes from different modules.
 <P>All data viewers can be moved and resized at will with the help of a
 simple internal window manager.
 <P>The current configuration (loaded modules, tables and viewers coordinates
-and sizes, poll time, main window size, ...) can the be saved in a file,
-so that an identical dashboard can be relaunched at a later time.
+and sizes, poll time, main window size, ...) can be saved in a file at
+any time, so that an identical dashboard can be relaunched at a later time.
 <H3>
 <A NAME="core"></A>5. Core</H3>
 
@@ -224,23 +230,17 @@ so that an identical dashboard can be relaunched at a later time.
 <A NAME="userinterface"></A>5.1. User interface</H4>
 Soon after the application launch, tabular data is displayed in one or
 more tkTable widgets with automatic scroll bars, between the menu bar,
-the drop sites with graphical viewers, summary table and trash icons and
-a message area, as one can see below:
+the drop sites with graphical viewers, summary table, free text and trash
+icons and a message area, as one can see below:
 <CENTER>
-<P><IMG SRC="moodss1.jpg" ALT="moodss initial main window view" HEIGHT=409 WIDTH=528></CENTER>
+<P><IMG SRC="moodss1.jpg" ALT="moodss initial main window view" HEIGHT=358 WIDTH=408></CENTER>
 
-<BR>&nbsp;
-<P><BR>
-<BR>
-<BR>
-<BR>
-<BR>
 <P>The message area is used to display status information, such as when
 the data is being updated, and help information, as the user moves the
 mouse pointer over sensitive areas, such as table column headers. Further
 help is provided through widget tips (also known as balloons) when appropriate,
 and of course the Help menu.
-<P>The window title shows the name of the current module along with the
+<P>The window title shows the name of the loaded module(s) along with the
 poll time.
 <P>The <I>File</I> menu contains the <I>Save</I>, <I>Save As</I> and <I>Exit</I>
 menu entries, used to save the current configuration (modules and viewers),
@@ -248,20 +248,9 @@ or gracefully quit the moodss application.
 <P>The <I>Options</I> menu (may not exist, see below) contains the <I>Poll
 time</I> entry which when selected launches the corresponding dialog box,
 as shown below:
-<BR>&nbsp;
-<BR>&nbsp;
-<BR>
-<BR>
-<BR>
 <CENTER>
 <P><IMG SRC="moodss2.jpg" ALT="poll time dialog box" HEIGHT=238 WIDTH=226></CENTER>
 
-<BR>&nbsp;
-<P><BR>
-<BR>
-<BR>
-<BR>
-<BR>
 <P>The user can select a new poll time among the module choices from a
 spin entry widget, or directly type in a new value, as long as it is not
 smaller than the module minimum poll time, in which case a message dialog
@@ -274,9 +263,9 @@ all modules poll times.
 <P>The <I>Poll time</I> menu entry is available only when needed, which
 is not the case if all the loaded modules are asynchronous. If this case,
 the <I>Options</I> menu itself is not displayed.
-<P>Table data can be sorted at any time by simply clicking on a column
-title. Clicking on the same column title again sorts the data in opposite
-order, thus toggling between increasing and decreasing orders.
+<P>Any data displayed in a table can be sorted at any time by simply clicking
+on a column title. Clicking on the same column title again sorts the data
+in opposite order, thus toggling between increasing and decreasing orders.
 <BR>When sorting, the selected column is used as a reference, meaning that
 all rows will be rearranged so that the selected column appears sorted,
 with values either increasing or decreasing.
@@ -295,75 +284,97 @@ and drop functionality described below.
 as can be seen below), side-by-side bars charts, overlapped bars charts
 (only available when the BLT version 2.4 library is used), stacked bars
 charts, 2D pie charts and 3D pie charts*.
-<BR>&nbsp;
-<CENTER><TABLE BORDER=0 COLS=2 WIDTH="100%" NOSAVE >
-<TR ALIGN=CENTER VALIGN=CENTER NOSAVE>
-<TD NOSAVE><IMG SRC="graph.jpg" ALT="graph viewer sample" HEIGHT=205 WIDTH=305></TD>
-
-<TD><IMG SRC="overbar.jpg" ALT="overlap bar chart viewer sample" HEIGHT=205 WIDTH=305></TD>
-</TR>
-
-<TR ALIGN=CENTER VALIGN=CENTER NOSAVE>
-<TD NOSAVE><IMG SRC="sidebar.jpg" ALT="side bar chart viewer sample" HEIGHT=205 WIDTH=305></TD>
-
-<TD><IMG SRC="stackbar.jpg" ALT="stacked bar chart viewer sample" HEIGHT=205 WIDTH=305></TD>
-</TR>
-
-<TR ALIGN=CENTER VALIGN=CENTER NOSAVE>
-<TD NOSAVE><IMG SRC="2dpie.jpg" ALT="2D pie chart viewer sample" HEIGHT=205 WIDTH=305></TD>
-
-<TD><IMG SRC="3dpie.jpg" ALT="3D pie chart viewer sample" HEIGHT=205 WIDTH=305></TD>
-</TR>
-
-<TR ALIGN=CENTER VALIGN=CENTER NOSAVE>
-<TD COLSPAN="2" NOSAVE><IMG SRC="sumtable.jpg" ALT="summary table viewer sample" HEIGHT=205 WIDTH=352></TD>
-
-<TD></TD>
-</TR>
-</TABLE></CENTER>
-
-<P>The textual viewer available at this time is the summary table: along
-with the cell label, the row columns are the current, average, minimum
-and maximum values since the table viewer was created.
 <P>*<I>note: if you know of any other nice viewers (like 3D graphs) that
 work with Tcl, please let me know so I can integrate them. Many thanks
 in advance...</I>
 <BR>&nbsp;
+<CENTER><TABLE COLS=2 WIDTH="100%" NOSAVE >
+<TR ALIGN=CENTER VALIGN=CENTER NOSAVE>
+<TD NOSAVE><IMG SRC="graph.jpg" ALT="graph viewer sample" HEIGHT=200 WIDTH=300></TD>
+
+<TD><IMG SRC="overbar.jpg" ALT="overlap bar chart viewer sample" HEIGHT=200 WIDTH=300></TD>
+</TR>
+
+<TR ALIGN=CENTER VALIGN=CENTER NOSAVE>
+<TD NOSAVE><IMG SRC="sidebar.jpg" ALT="side bar chart viewer sample" HEIGHT=200 WIDTH=300></TD>
+
+<TD><IMG SRC="stackbar.jpg" ALT="stacked bar chart viewer sample" HEIGHT=200 WIDTH=300></TD>
+</TR>
+
+<TR ALIGN=CENTER VALIGN=CENTER NOSAVE>
+<TD NOSAVE><IMG SRC="2dpie.jpg" ALT="2D pie chart viewer sample" HEIGHT=200 WIDTH=300></TD>
+
+<TD><IMG SRC="3dpie.jpg" ALT="3D pie chart viewer sample" HEIGHT=200 WIDTH=300></TD>
+</TR>
+</TABLE></CENTER>
+
+<CENTER><TABLE WIDTH="100%" NOSAVE >
+<TR ALIGN=CENTER VALIGN=CENTER NOSAVE>
+<TD WIDTH="58%" NOSAVE><IMG SRC="sumtable.jpg" ALT="summary table viewer sample" HEIGHT=200 WIDTH=350></TD>
+
+<TD WIDTH="42%" NOSAVE><IMG SRC="freetext.jpg" ALT="free text viewer sample" HEIGHT=200 WIDTH=250></TD>
+</TR>
+</TABLE></CENTER>
+
+<P>There are 2 textual viewers.
+<BR>The summary table displays for each row the cell label, the current,
+average, minimum and maximum values since the row was created.
+<BR>The free text viewer is an editable Tcl text widget with any number
+(including zero) of embedded data cell windows. Data cells can be inserted
+one or several at a time through a simple drop, as with the other viewers.
+New data cell windows are inserted at the current insertion cursor position.
+Data cells can be deleted by selecting then dropping any number of them
+into the trash drop site. They can also be deleted using the keyboard Delete
+and Backspace keys, which also work on the regular text, as well as the
+expected other key bindings. When dropping data cells, each data cell window
+is preceded by a relevant label text for the cell, which can later be edited
+at any time.
+<P>Here is a screen shot of loaded <I>ps</I> and <I>cpustats</I> modules
+with several graphical viewers:
 <BR>&nbsp;
-<BR>
 <CENTER>
 <H5>
-<IMG SRC="moodss3.jpg" ALT="moodss window with graph data viewers" HEIGHT=633 WIDTH=574></H5></CENTER>
+<IMG SRC="moodss3.jpg" ALT="moodss window with graph data viewers" HEIGHT=611 WIDTH=578></H5></CENTER>
 All data viewers can be moved and resized thanks to handling areas in the
 data viewer borders. When moving the mouse pointer over these areas, the
 mouse cursor changes to indicate the possible action. Corner handles allow
-resizing in both x and y axis. Handles in the middle of the sides allow
-resizing in either the x or y axis direction. All other areas can be used
-for moving the data viewer. Clicking on any part of the border changes
-the stacking order: the viewer being clicked on either goes below (eventually
-becomes hidden) the other viewers, or becomes fully visible (on top, eventually
-hiding other viewers). Further description of this small window manager
-functionality is useless, as it behaves like a basic window manager (let
-me know if it does not).
+resizing in both X and Y axis. Handles in the middle of the sides allow
+resizing in either the X or Y axis direction. All other areas can be used
+for moving the data viewer as shown by the quadruple arrow cursor. Clicking
+on any part of the border changes the stacking order: the viewer being
+clicked on either goes below (eventually becomes hidden) the other viewers,
+or becomes fully visible (on top, eventually hiding other viewers). When
+moving or resizing, the message area displays the current coordinates or
+size in real time as the mouse is being moved. Further description of this
+small window manager functionality is useless, as it behaves like a basic
+window manager (let me know if it does not).
+<P>Here is another shot featuring a free text viewer with loaded <I>cpustats</I>
+and <I>memstats</I> modules:
+<CENTER>
+<P><IMG SRC="moodss4.jpg" HEIGHT=475 WIDTH=467></CENTER>
+
 <P>The <I>Help</I> menu contains <I>Global</I> help (actually launches
 an embedded HTML viewer with this very document), <I>Modules</I> help which
-displays all the loaded modules help texts, and <I>About</I> general information
-entries.
+displays all the loaded modules help texts, <I>Copyright</I> which displays
+the GPL (Gnu General Public License) document, <I>Source Versions </I>which
+display all the source code file names with their versions and <I>About</I>
+general information entries.
 <H5>
 <A NAME="draganddrop"></A>5.1.1 Drag and drop</H5>
-Drag and drop in moodss tries to behave as the familiar Windows functionality
-(no, it doesn't mean I am a Bill Gates fan :). For example, to create a
-graphical plot, one must first select one or more data cells in a data
-table, hold down the first mouse button (the left one for a right handed
-user) while dragging over to the left-most icon below the menu bar (when
-dragging an object, as the mouse pointer passes over possible drop sites,
-they are highlighted with a thin black border for user feedback). Releasing
-the mouse button at this time results in the creation of a BLT graph viewer.
+Drag and drop in moodss tries to behave as the now familiar Windows functionality
+(no, it doesn't mean I am a Bill Gates fan, as they probably stole the
+idea from somebody else anyway :^). For example, to create a graphical
+plot, one must first select one or more data cells in a data table, hold
+down the first mouse button (the left one for a right handed user) while
+dragging over to the left-most icon below the menu bar (when dragging an
+object, as the mouse pointer passes over possible drop sites, they are
+highlighted with a thin black border for user feedback). Releasing the
+mouse button at this time results in the creation of a BLT graph viewer.
 <P>Only valid drop sites for the data being dragged are highlighted when
 the mouse cursor passes over them, thus guaranteeing error free operations
 (if there are no bugs, that is :).
 <P>In summary, data cells can be dragged from any table or any viewer into
-any viewer icon, any viewer or the trash can.
+any viewer drop site icon, any viewer or the trash can.
 <H6>
 <A NAME="dropsites"></A>5.1.1.1. Drop sites</H6>
 All icons right below the menu bar are valid drop sites for data cells
@@ -387,6 +398,9 @@ stacked bar chart with one or more data bars created at once</LI>
 <LI>
 summary table with one or more data rows created at once</LI>
 
+<LI>
+free text with one or more labelled data cell windows created at once</LI>
+
 <LI>
 object trash with one or more data viewer elements deleted at once</LI>
 </UL>
@@ -398,22 +412,24 @@ directly in the viewer results in corresponding lines, bars, slices or
 rows being created and automatically updated. Each new graphical element
 is assigned a new and different color.
 <P>You may delete one or more viewer elements (graph lines, bar chart bars,
-pie charts slices or summary table rows) from a viewer by selecting them
-(using the first mouse button) through their labels. Several elements can
-be selected by depressing the control key as the first mouse button is
-pressed. The selection can also be extended by depressing the shift key
-along with the first mouse button. The pie slices can also be directly
-selected by clicking on the slices themselves.
+pie charts slices, summary table rows or free text cell window) from a
+viewer by selecting them (using the first mouse button) through their labels.
+Several elements can be selected by depressing the control key as the first
+mouse button is pressed. The selection can also be extended by depressing
+the shift key along with the first mouse button. The pie slices can also
+be directly selected by clicking on the slices themselves.
 <BR>Then dragging from the viewer to the trash drop site (the bullet hole)
 on the upper right side of the main window and releasing the first mouse
 button result in the corresponding viewer elements to be destroyed. If
 there are no remaining elements, the viewer itself (graph, bar chart, pie
-or table) is destroyed.
+or summary table) is destroyed. The free text viewer can only be deleted
+when completely emptied of any text and data cell window:&nbsp;it can then
+be dropped into the trash.
 <H6>
 <A NAME="dragsites"></A>5.1.1.2. Drag sites</H6>
 A table is obviously a drag site. One or more cells can be dragged at once
-after selection, using the traditional single / shift / control mouse click
-techniques.
+after selection, using the traditional single/shift/control mouse click
+technique.
 <P>Any viewer is also a drag site. It requires selecting one or more viewer
 elements before initiating the drag operation from any selected element
 in the viewer. If there are no selected elements, dragging is impossible:
@@ -428,8 +444,8 @@ can be saved in a file, which achieves a dashboard functionality.
 have been moved, resized, viewers created, moved and resized, the current
 configuration can be saved in a .moo file, and later reused by passing
 the corresponding file name with the -f (--file) command line switch.
-<P>For moodss version 4.0, the following information is saved in the file
-(which is human readable):
+<P>For moodss version 4.0 and above, the following information is saved
+in the file (which is human readable):
 <UL>
 <LI>
 moodss version</LI>
@@ -450,17 +466,17 @@ modules</LI>
 tables positions and sizes</LI>
 
 <LI>
-viewers types, positions and sizes</LI>
+viewers types, positions, sizes and specific data</LI>
 </UL>
-When using the File Save menu for the first time, and if a file name was
-not specified in the command line, the file selector dialog box appears
-so that the user may choose a file name (with a .moo extension).
-<P>The File Save As menu behaves as expected, with the user always having
-to choose a file name.
+When using the <I>File Save</I> menu for the first time, and if a file
+name was not specified in the command line, the file selector dialog box
+appears so that the user may choose a file name (with a .moo extension).
+<P>The <I>File Save As</I> menu behaves as expected, with the user always
+having to choose a file name.
 <P>Once a file name has been specified (either through the command line
 or the file selector dialog box), that file name is reused whenever the
-File Save menu is used. The File Save As menu may be used at any time to
-change the file name.
+<I>File Save</I> menu is used. The <I>File Save As</I> menu may be used
+at any time to change the file name.
 <H4>
 <A NAME="commandline"></A>5.2. Command line</H4>
 Launching moodss is very simple: just pass one or more data module names
@@ -728,10 +744,10 @@ where it was installed. <I>1.1</I> is the version number for the package.
 The current directory (.) is appended to the <I>auto_load</I> global list
 variable so that sample modules can be found when moodss is run from the
 unpacking directory.
-<P>For example, if you unpacked moodss in <I>/home/joe/moodss-4.x/</I>,
-you will find the random module package in <I>/home/joe/moodss-4.x/random/</I>
+<P>For example, if you unpacked moodss in <I>/home/joe/moodss-5.x/</I>,
+you will find the random module package in <I>/home/joe/moodss-5.x/random/</I>
 so that the following will work:
-<PRE>$ cd /home/joe/moodss-4.x/
+<PRE>$ cd /home/joe/moodss-5.x/
 $ wish moodss random</PRE>
 You can install your new modules in the default location: <I>/usr/local/lib/</I>
 on Unix. For example, if you move the files in <I>/home/joe/moodss-4.x/random/</I>
