@@ -1,7 +1,7 @@
 # copyright (C) 1997-98 Jean-Luc Fontaine (mailto:jfontain@mygale.org)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: lifolbl.tcl,v 1.10 1998/05/24 19:24:43 jfontain Exp $}
+set rcsId {$Id: lifolbl.tcl,v 1.11 1998/10/09 19:36:40 jfontain Exp $}
 
 # last-in-first-out label generally used at the bottom of an application window for messages display
 
@@ -71,6 +71,6 @@ proc lifoLabel::pop {this} {
 }
 
 proc lifoLabel::flash {this string {seconds 1}} {                                            ;# user procedure for flashing a string
-    after [expr 1000*$seconds] lifoLabel::pop $this
+    after [expr {1000*$seconds}] lifoLabel::pop $this
     push $this $string
 }
