@@ -1,7 +1,7 @@
 # copyright (C) 1997-98 Jean-Luc Fontaine (mailto:jfontain@mygale.org)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: record.tcl,v 1.6 1998/09/06 20:39:17 jfontain Exp $}
+set rcsId {$Id: record.tcl,v 1.8 1998/10/17 20:40:52 jfontain Exp $}
 
 
 class record {
@@ -63,6 +63,10 @@ class record {
             foreach {x y width height} [canvasWindowManager::getGeometry $::windowManager $widget::($viewer,path)] {}
             puts $file "        x $x y $y width $width height $height"
             puts $file "        cells {[viewer::cells $viewer]}"
+            set options [viewer::initializationConfiguration $viewer]
+            if {[llength $options]>0} {
+                puts $file "        $options"
+            }
             puts $file "    \}"
             incr index
         }
@@ -108,7 +112,11 @@ class record {
         set list {}
         foreach index [lsort -integer [array names data]] {
             array set viewer $data($index)
-            lappend list $viewer(class) $viewer(cells) $viewer(x) $viewer(y) $viewer(width) $viewer(height)
+            set options {}                                  ;# gather viewer specific switched options in a switch / value pair list
+            foreach name [array names viewer -*] {
+                lappend options $name $viewer($name)
+            }
+            lappend list $viewer(class) $viewer(cells) $viewer(x) $viewer(y) $viewer(width) $viewer(height) $options
         }
         return $list
     }
