@@ -1,4 +1,4 @@
-set rcsId {$Id: scroll.tcl,v 1.5 1998/04/30 17:33:03 jfontain Exp $}
+set rcsId {$Id: scroll.tcl,v 1.9 1998/10/04 14:57:52 jfontain Exp $}
 
 # generic scroll widget with automatic scrollbars for scrolling widgets with the common tk scroll interface
 
@@ -8,13 +8,15 @@ class scroll {
         # scrollable class widget must accept the -[xy]scrollcommand options and [xy]view commands, such as canvas, text, table, ...
         set path $widget::($this,path)
         composite::manage $this [new $scrollableClass $path] scrolled\
-            [new scrollbar $path -orient horizontal] horizontal [new scrollbar $path] vertical
+            [new scrollbar $path -orient horizontal] horizontal [new scrollbar $path] vertical [new frame $path] filler
 
         widget::configure $composite::($this,scrolled)\
             -xscrollcommand "scroll::update $this 1 0" -yscrollcommand "scroll::update $this 0 1"
         widget::configure $composite::($this,horizontal) -command "$composite::($this,scrolled,path) xview"
         widget::configure $composite::($this,vertical) -command "$composite::($this,scrolled,path) yview"
 
+        grid propagate $widget::($this,path) 0                  ;# turn off propagation so that setting width and height is possible
+
         grid $composite::($this,scrolled,path) -sticky nsew
         grid rowconfigure $path 0 -weight 1
         grid columnconfigure $path 0 -weight 1
@@ -30,8 +32,21 @@ class scroll {
     proc options {this} {
         return [list\
             [list -automatic automatic Automatic 1 1]\
+            [list\
+                -scrollbarborderwidth scrollbarBorderWidth ScrollbarBorderWidth\
+                $widget::(default,ScrollbarBorderWidth) $widget::(default,ScrollbarBorderWidth)\
+            ]\
+            [list\
+                -scrollbarelementborderwidth scrollbarElementBorderWidth ScrollbarElementBorderWidth\
+                $widget::(default,ScrollbarElementBorderWidth) $widget::(default,ScrollbarElementBorderWidth)\
+            ]\
+            [list\
+                -scrollbarwidth scrollbarWidth ScrollbarWidth $widget::(default,ScrollbarWidth) $widget::(default,ScrollbarWidth)\
+            ]\
+            [list -height height Height $widget::(default,CanvasHeight)]\
             [list -horizontal horizontal Horizontal 1 1]\
             [list -vertical vertical Vertical 1 1]\
+            [list -width width Width $widget::(default,CanvasWidth)]\
         ]
     }
 
@@ -43,6 +58,21 @@ class scroll {
         "
     }
 
+   foreach option {borderwidth elementborderwidth width} {
+        proc set-scrollbar$option {this value} "
+            \$composite::(\$this,vertical,path) configure -$option \$value
+            \$composite::(\$this,horizontal,path) configure -$option \$value
+        "
+    }
+
+    proc set-height {this value} {
+        $widget::($this,path) configure -height $value
+    }
+
+    proc set-width {this value} {
+        $widget::($this,path) configure -width $value
+    }
+
     proc update {this row column first last} {
         set path $scroll::($this,$row,$column,path)
         foreach {previousFirst previousLast} [$path get] {}
@@ -58,12 +88,14 @@ class scroll {
                 if {$composite::($this,-horizontal)} {
                     grid $composite::($this,horizontal,path) -row 1 -column 0 -sticky nsew
                 }
+                grid $composite::($this,filler,path) -sticky nsew -column 1 -row 1
             }
         } else {
             foreach {first last} [$scroll::($this,$column,$row,path) get] {}                        ;# look at other scrollbar range
             if {$visible&&(($last-$first)>=1)} {                       ;# unmap both scrollbars at the same time to avoid vibrations
                 grid remove $scroll::($this,0,1,path)
                 grid remove $scroll::($this,1,0,path)
+                grid remove $composite::($this,filler,path)
             }
         }
     }
