@@ -1,7 +1,7 @@
 # copyright (C) 1997-98 Jean-Luc Fontaine (mailto:jfontain@mygale.org)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: utility.tcl,v 1.3 1998/05/24 19:24:43 jfontain Exp $}
+set rcsId {$Id: utility.tcl,v 1.4 1998/09/18 21:18:30 jfontain Exp $}
 
 proc minimum {a b} {return [expr {$a<$b?$a:$b}]}
 proc maximum {a b} {return [expr {$a>$b?$a:$b}]}
@@ -16,3 +16,13 @@ proc ldelete {listName value} {
     set list [lreplace $list $index $index]
 
 }
+
+proc startGatheringRCSIds {} {
+    trace variable ::rcsId w recordRCSId
+}
+
+proc recordRCSId {variableName empty operation} {
+    foreach {header file version} $::rcsId break
+    regsub {,v$} $file {} file
+    set ::sourceVersion($file) $version
+}
